==> Strawberry_PI-0.0.62-py3-none-any.whl: LoRa/boards/board_rpi.py <==
import RPi.GPIO as GPIO  # type:ignore
import spidev  # type:ignore

from .board import Board as IBoard


class Board(IBoard):
    def __init__(self):
        GPIO.setmode(GPIO.BCM)  # type: ignore -> Così posso utilizzare i numeri

        super().__init__(
            8,
            10,
            9,
            11,
            22,
            4,
            17,
            18,
            27,
            None,
            None,
        )

    # -------------------------------------------------------------------------------------------- #
    def pin(self, id: int | None, in_out: object = GPIO.OUT) -> None:  # type: ignore
        if id is not None:
            GPIO.setup(id, in_out, pull_up_down=GPIO.PUD_DOWN)  # type: ignore

    def spi(self) -> object:
        spi = spidev.SpiDev()  # type: ignore
        spi.open(0, 0)  # type: ignore
        spi.max_speed_hz = 5000000  # type: ignore

        return spi  # type: ignore

    def add_event(self, pin: int | None, callback: object) -> None:
        if pin is not None:
            self.pin(pin, GPIO.IN)  # type: ignore
            GPIO.add_event_detect(pin, GPIO.RISING, callback=callback)  # type: ignore

    # -------------------------------------------------------------------------------------------- #
    def _write(self, reg: int, value: list[int]) -> None:
        self._spi.xfer([reg | 0x80] + payload)  # type: ignore

    def Read(self, reg: int) -> int:
        return self._spi.xfer([reg] + [0])[1]  # type: ignore

    def Reads(self, reg: int, length: int) -> list[int]:
        return self._spi.xfer([reg] + [0] * length)[1:]  # type: ignore

==> Strawberry_PI-0.0.63-py3-none-any.whl: LoRa/boards/board_rpi.py <==
import RPi.GPIO as GPIO  # type:ignore
import spidev  # type:ignore

from .board import Board as IBoard


class Board(IBoard):
    def __init__(self):
        GPIO.setmode(GPIO.BCM)  # type: ignore -> Così posso utilizzare i numeri

        super().__init__(
            8,
            10,
            9,
            11,
            22,
            4,
            17,
            18,
            27,
            None,
            None,
        )

    # -------------------------------------------------------------------------------------------- #
    def pin(self, id: int | None, in_out: object = GPIO.OUT) -> None:  # type: ignore
        if id is not None:
            GPIO.setup(id, in_out, pull_up_down=GPIO.PUD_DOWN)  # type: ignore

    def spi(self) -> object:
        spi = spidev.SpiDev()  # type: ignore
        spi.open(0, 0)  # type: ignore
        spi.max_speed_hz = 5000000  # type: ignore

        return spi  # type: ignore

    def add_event(self, pin: int | None, callback: object) -> None:
        if pin is not None:
            self.pin(pin, GPIO.IN)  # type: ignore
            GPIO.add_event_detect(pin, GPIO.RISING, callback=callback)  # type: ignore

    # -------------------------------------------------------------------------------------------- #
    def _write(self, reg: int, value: list[int]) -> None:
        self._spi.xfer([reg | 0x80] + value)

    def Read(self, reg: int) -> int:
        return self._spi.xfer([reg] + [0])[1]

    def Reads(self, reg: int, length: int) -> list[int]:
        return self._spi.xfer([reg] + [0] * length)[1:]


Any = object()
